.. _ReferencePage:

=============
API Reference
=============

You can find automatically generated documentation for each module in the ``nemo`` package below. Note that 
some functions listed here may not be used by any of the scripts found in the ``bin/`` directory.

catalogs
--------

.. automodule:: nemo.catalogs
   :members:

completeness
------------

.. automodule:: nemo.completeness
   :members:

filters
-------

.. automodule:: nemo.filters
   :members:


gnfw
----

.. automodule:: nemo.gnfw
   :members:

maps
----

.. automodule:: nemo.maps
   :members:


MockSurvey
----------

.. automodule:: nemo.MockSurvey
   :members:


photometry
----------

.. automodule:: nemo.photometry
   :members:


pipelines
---------

.. automodule:: nemo.pipelines
   :members:


plotSettings
------------

.. automodule:: nemo.plotSettings
   :members:


signals
-------

.. automodule:: nemo.signals
   :members:


startUp
-------

.. automodule:: nemo.startUp
   :members:
